@@ -4,34 +4,30 @@ import json
 import hashlib
 
 def add_padding (s):
-	l = []
-	for each in s:
-		paddings = 4 - (len (each) % 4)
-		if paddings != 4:
-			each += "=" * paddings
-		l.append (each)	
-	return tuple (l)
+	paddings = 4 - (len (s) % 4)
+	if paddings != 4:
+		s += "=" * paddings
+	return s	
 			
 def get_claim (secret_key, token):
-	header, claim, sig = add_padding (token.split ("."))
-	
-	jheader = json.loads (b64decode (header).decode ("utf8"))
-	alg = jheader.get ("alg")	
+	header, claim, sig = token.split (".")	
+	jheader = json.loads (b64decode (add_padding (header)).decode ("utf8"))
+	alg = jheader.get ("alg")
 	if not alg or alg [:2] != "HS":
 		return	
 	hash_method = getattr (hashlib, "sha" + alg [2:])	
 	mac = hmac (secret_key, None, hash_method)
 	mac.update (("%s.%s" % (header, claim)).encode ("utf8"))
-	if mac.digest() != b64decode (sig):
+	if mac.digest() != b64decode (add_padding (sig)):
 		return
-	return json.loads (b64decode (claim).decode ("utf8"))
+	return json.loads (b64decode (add_padding (claim)).decode ("utf8"))
 	
 def gen_token (secret_key, claim, alg = "HS256"):
 	header = b64encode (json.dumps ({"alg": alg, "typ": "JWT"}).encode ("utf8")).rstrip (b'=')
 	claim = b64encode (json.dumps (claim).encode ("utf8")).rstrip (b'=')
 	hash_method = getattr (hashlib, "sha" + alg [2:])	
 	mac = hmac (secret_key, None, hash_method)
-	mac.update (header + b"." + claim)
+	mac.update (header + b"." + claim)	
 	sig = b64encode (mac.digest()).rstrip (b'=')
 	return (header + b"." + claim + b"." + sig).decode ("utf8")
 
