@@ -9,14 +9,16 @@ import codecs
 
 PY_MAJOR_VERSION = sys.version_info.major
 
-def trace ():
-	(file,fun,line), t, v, tbinfo = asyncore.compact_traceback()
-	try:
-		v = str (v)
-	except:	
-		v = repr (v)
-		
-	return "%s %s Traceback: %s" % (t, v, tbinfo)
+def trace (multirows = False):
+	(file, fun, line), t, v, tbinfo = asyncore.compact_traceback()
+	try: v = str (v)
+	except:	v = repr (v)
+	line = "%s %s Traceback: %s" % (t, v, tbinfo)
+	if multirows:
+		line = trace ().replace ("] [", "\n  - ")
+		line = line.replace ("Traceback: [", "\n  -----------\n  + Traceback\n  ===========\n  - ")
+		line = line [:-1] + "\n  -----------"
+	return line
 		
 def now (detail = 1):
 	if detail: return time.strftime("%Y.%m.%d %H:%M:%S", time.localtime(time.time()))
@@ -97,7 +99,7 @@ class base_logger:
 		self.out.close ()
 	
 	def trace (self, name = ''):
-		return self.log (trace (), "expt", name)	
+		return self.log (trace (True), "expt", name)	
 	traceback = trace	
 	
 	def read (self):
@@ -107,14 +109,7 @@ class base_logger:
 class screen_logger (base_logger):
 	def __init__ (self, cacheline = 200, flushnow = 1):
 		base_logger.__init__(self, sys.stdout, cacheline, flushnow)
-	
-	def log (self, line, type = "info", name = ""):
-		if type.startswith ("expt"):
-			line = trace ().replace ("] [", "\n  - ")
-			line = line.replace ("Traceback: [", "\n  -----------\n  + Traceback\n  ===========\n  - ")
-			line = line [:-1] + "\n  -----------"
-		base_logger.log (self, line, type, name)			
-	
+		
 	def close (self): 
 		pass
 
@@ -269,14 +264,12 @@ class multi_logger (base_logger):
 	def rotate (self):
 		for logger in self.loggers:
 			hasattr (logger, 'rotate') and logger.rotate ()
-			
+	
 	def log (self, line, type="info", name=""):
 		if self.filter and type not in self.filter:
 			return line
-		
 		for logger in self.loggers:
-			_lline = logger.log (line, type, name)	
-				
+			_lline = logger.log (line, type, name)				
 		self.cache (_lline)
 		
 	def add_logger (self, logger):
@@ -287,8 +280,6 @@ class multi_logger (base_logger):
 			logger.close ()
 
 
-
-
 if __name__ == "__main__":
 	l = file_logger ("x:/test/", "test")			
 	for i in range (300):
