@@ -160,9 +160,11 @@ class Response:
 		ct = self.get_header ("content-type", "")
 		if ct.startswith ('application/grpc'):
 			self.p, self.u = buffers.getfakeparser (grpc_buffer, cache = self.max_age)
-		elif ct == 'text/xml' and self.request.xmlrpc_serialized ():
+		elif ct.startswith ('text/xml') and self.request.xmlrpc_serialized ():
 			self.p = self.u = buffers.cachable_xmlrpc_buffer (self.max_age)
 			self.is_xmlrpc_return = True
+		elif ct.startswith ('application/json-rpc'):
+			self.p = self.u = buffers.cachable_jsonrpc_buffer (self.max_age)				
 		else:			
 			self.p, self.u = buffers.getfakeparser (buffers.bytes_buffer, cache = self.max_age)
 			
@@ -373,6 +375,9 @@ class Response:
 			if len (result) == 1:
 				result = result [0]
 			return result
+		
+		elif ct.startswith ("application/json-rpc"):
+			return json.loads (result) ["result"]
 			
 		elif ct.startswith ("application/json"):
 			return json.loads (result.decode ("utf8"))
@@ -380,14 +385,14 @@ class Response:
 		elif ct.startswith ('application/grpc'):			
 			msgs = []
 			for msg in result:
-				descriptor, isstream = discover.find_output (self.request.path [1:])					
-				f = descriptor ()
-				f.ParseFromString (msg.decode ("utf8"))
+				descriptor, isstream = discover.find_output (self.request.path [1:])			
+				f = descriptor ()				
+				f.ParseFromString (msg)
 				msgs.append (f)
 								
 			if not isstream:
 				return msgs [0]
-			return msgs	
+			return msgs
 		
 		self.__data_cache = result	
 		return result
